@@ -87,6 +87,11 @@ def create_parser():
         action='store_true',
         help="Print verbose output"
     )
+    group_general.add_argument(
+        '-q', '--quiet',
+        action='store_true',
+        help="Only print errors in output"
+    )
     group_general.add_argument(
         '-n', '--dry-run',
         action='store_true',
@@ -237,8 +242,6 @@ def create_parser():
         help=textwrap.dedent("""\
         Add an audio filter chain before applying normalization.
         Multiple filters can be specified by comma-separating them.
-
-        For EBU, the filter will be applied during the second pass.
         """)
     )
     group_acodec.add_argument(
@@ -333,7 +336,9 @@ def create_parser():
 def main():
     cli_args = create_parser().parse_args()
 
-    if cli_args.debug:
+    if cli_args.quiet:
+        logger.setLevel(logging.ERROR)
+    elif cli_args.debug:
         logger.setLevel(logging.DEBUG)
     elif cli_args.verbose:
         logger.setLevel(logging.INFO)
@@ -397,7 +402,7 @@ def main():
                 os.makedirs(cli_args.output_folder)
 
         if os.path.exists(output_file) and not cli_args.force:
-            logger.warning(
+            logger.error(
                 "Output file {} already exists, skipping. Use -f to force overwriting.".format(output_file)
             )
         else:
