@@ -6,11 +6,7 @@ import os
 import sys
 import unittest
 import subprocess
-
-try:
-  from pathlib import Path
-except ImportError:
-  from pathlib2 import Path  # python2 backport
+from pathlib import Path
 
 sys.path.append(os.path.abspath(os.path.dirname(__file__) + '/../'))
 
@@ -153,6 +149,10 @@ class TestFFmpegNormalize(unittest.TestCase):
         output, _ = ffmpeg_normalize_call(['test/test.wav', '-pof', 'volume=0,volume=0'])
         self.assertTrue(os.path.isfile('normalized/test.mkv'), msg=output)
 
+    def test_quiet(self):
+        output, _ = ffmpeg_normalize_call(['test/test.mp4', '-ext', 'wav', '-vn', '-f', 'q'])
+        self.assertTrue("only supports one stream" not in output, msg=output)
+
     def tearDown(self):
         for file in ['test.mkv', 'test.wav', 'test.mp3', 'test.aac', 'test.mp4']:
             if os.path.isfile('normalized/' + file):
